# Contributing to mne-qt-browser

**Thank you very much for taking the time to contribute!** :+1::+1::+1:

As this package is a subsidiarian of [MNE-Python](https://mne.tools/dev/index.html)
its [guidelines](https://github.com/mne-tools/mne-python) for contributing apply as well.

## Setting up development environment
Follow the [instructions from mne-python](https://mne.tools/dev/install/contributing.html#setting-up-your-local-development-environment)
and additionally install the dependencies for this repository:

```
pip install -r requirements_testing.txt
```
